@@ -2,6 +2,7 @@
 module Generics.Deriving (
 
     module Generics.Deriving.Base,
+    module Generics.Deriving.Copoint, 
     module Generics.Deriving.ConNames,
     module Generics.Deriving.Enum,
     module Generics.Deriving.Eq,
@@ -12,6 +13,7 @@ module Generics.Deriving (
   ) where
 
 import Generics.Deriving.Base
+import Generics.Deriving.Copoint
 import Generics.Deriving.ConNames
 import Generics.Deriving.Enum
 import Generics.Deriving.Eq
